# Modeling SAP Cloud Solutions
### On this page
  * [SAP Cloud Solutions Modeling Perspectives](https://help.sap.com/docs/leanix/ea/modeling-sap-cloud-solutions#sap-cloud-solutions-modeling-perspectives)
  * [SAP Cloud Solutions Modeling Best Practices and Guidelines](https://help.sap.com/docs/leanix/ea/modeling-sap-cloud-solutions#sap-cloud-solutions-modeling-best-practices-and-guidelines)
  * [Handling Multiple Instances of SAP Cloud Solutions](https://help.sap.com/docs/leanix/ea/modeling-sap-cloud-solutions#handling-multiple-instances-of-sap-cloud-solutions)
  * [Modeling SAP Systems](https://help.sap.com/docs/leanix/ea/modeling-sap-cloud-solutions#modeling-sap-systems)
  * [Modeling Instance Strategy With System Fact Sheets](https://help.sap.com/docs/leanix/ea/modeling-sap-cloud-solutions#modeling-instance-strategy-with-system-fact-sheets)


Understand the business and technical perspectives of modeling SAP Cloud Solutions and learn how to model them in SAP LeanIX.
